@@ -106,14 +106,16 @@ def _get_git_version():
     something unexpected"""
     try:
         cmd = 'git --version'
-        _, version, _ = run_shell_command(cmd, shell=True)
+        value, version, _ = run_shell_command(cmd, shell=True)
+        if value != 0:
+            raise VcsError("git --version returned %s, maybe git is not installed"%(value))
+        prefix = 'git version '
+        if version is not None and version.startswith(prefix):
+            version = version[len(prefix):].strip()
+        else:
+            raise VcsError("git --version returned invalid string: '%s'"%version)
     except VcsError as e:
-        raise VcsError("git not installed")
-    prefix = 'git version '
-    if version.startswith(prefix):
-        version = version[len(prefix):].strip()
-    else:
-        raise VcsError("git --version returned invalid string: '%s'"%version)
+        raise VcsError("Could not determine whether git is installed: %s"%e)
     return version
 
 class GitClient(VcsClientBase):
@@ -230,7 +232,7 @@ class GitClient(VcsClientBase):
                 # prevent commit from becoming dangling
                 if self.is_commit_in_orphaned_subtree(current_version, fetch = need_to_fetch):
                     # commit becomes dangling unless we move to one of its descendants
-                    if not self.rev_list_contains(refname, [current_version], fetch = False):
+                    if not self.rev_list_contains(refname, current_version, fetch = False):
                         # TODO: should raise error instead of printing message
                         print "vcstools refusing to move away from dangling commit, to protect your work."
                         return False
@@ -268,6 +270,7 @@ class GitClient(VcsClientBase):
             command += " --format='%H'"
             _, output, _ = run_shell_command(command, shell=True, cwd=self._path)
             return output
+        return None
 
     def get_diff(self, basepath=None):
         response = ''
